
# C3 = Compact Crypto Certs

Compact Crypto Certs (C3) is a mini-PKI signer/verifier with full chain functionality and compact binary and friendly text cert formats

(Note: a libsodium DLL/so/dylib is needed for the private key password encryption)